/*******************************************************************************
 * Copyright (c) 2016 ALL4TEC & CEA LIST.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     ALL4TEC & CEA LIST - initial API and implementation
 ******************************************************************************/
package org.polarsys.esf.core.ui.wizards.saproject;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.INewWizard;
import org.eclipse.ui.IWorkbench;
import org.polarsys.esf.core.common.ui.selection.SelectAndRevealResourceJob;
import org.polarsys.esf.core.common.ui.wizard.AbstractGenericWizard;
import org.polarsys.esf.core.ui.CoreUIActivator;
import org.polarsys.esf.core.ui.CoreUIActivator.Implementation;

/**
 * Define the UI of the wizard used to create new ESF Project.
 * 
 * @author $Author: jdumont $
 * @version $Revision: 83 $
 */
public class ESFProjectWizard
    extends AbstractGenericWizard
    implements INewWizard {

    /** Project creation success message. */
    private static final String PROJECT_CREATION_SUCCESSFUL = CoreUIActivator.getMessages().getString(
        "ESFProjectWizard.task.success"); //$NON-NLS-1$;

    /** This is the project creation page of this wizard. */
    private ESFProjectWizardProjectCreationPage mNewProjectCreationPage = null;

    /** Remember the selection during initialisation. */
    private IStructuredSelection mSelection = null;

    /** Project creation state. */
    private ProjectCreationState mCreationState = null;

    /**
     * Constructor for this wizard.
     */
    public ESFProjectWizard() {
        super(PROJECT_CREATION_SUCCESSFUL, false);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public final void init(final IWorkbench pWorkbench, final IStructuredSelection pSelection) {
        // Save the selection
        mSelection = pSelection;

        // Set the window title
        setWindowTitle(CoreUIActivator.getMessages().getString("ESFProjectWizard.title"));

        // Set the default page image
        setDefaultPageImageDescriptor(CoreUIActivator.getPlugin().getImageRegistry()
            .getDescriptor(Implementation.ICON_WIZARD_SA_PROJECT));

    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void prepareFinish() {

        mCreationState = new ProjectCreationState();

        mCreationState.setProjectName(mNewProjectCreationPage.getProjectName());
        mCreationState.setLocationURI(mNewProjectCreationPage.getLocationURI());
        mCreationState.setUseDefault(mNewProjectCreationPage.useDefaults());
        mCreationState.setModelName(mNewProjectCreationPage.getModelName());
        mCreationState.setFearedEventsLibraryName(mNewProjectCreationPage.getFearedEventsLibraryName());

        // Get the selected working sets
        mCreationState.setWorkingSetsArray(mNewProjectCreationPage.getSelectedWorkingSets());
    }

    /**
     * Create project, then model file, then aird.
     * 
     * {@inheritDoc}
     */
    @Override
    protected IStatus doFinish(final IProgressMonitor pMonitor) {

        // Execute command with correct state
        ProjectCreationCommand vCommand = new ProjectCreationCommand(mCreationState);
        IStatus vStatus = vCommand.execute(pMonitor);

        if (vStatus == null || vStatus.isOK()) {
            SelectAndRevealResourceJob vSelectJob = new SelectAndRevealResourceJob(
                vCommand.getCreatedProject());
            vSelectJob.schedule();
        }

        return vStatus;

    }

    /**
     * {@inheritDoc}
     */
    @Override
    public final void addPages() {
        // Call the parent method
        super.addPages();

        /*
         * Add the pages to create a new ESF project
         */

        // Create the page for the project creation
        mNewProjectCreationPage =
            new ESFProjectWizardProjectCreationPage(
                ESFProjectWizardProjectCreationPage.class.getName(),
                mSelection);

        // Add the page to the wizard
        addPage(mNewProjectCreationPage);
    }
}
